@@ -1,12 +1,13 @@
 
 from .private.bar_plotter import BarPlotter as BarPlotter
+from .private.box_plotter import BoxPlotter
+from .private.disc_heat_plotter import DiscreteHeatMapPlotter
 from .private.histogram_plotter import HistogramPlotter
 from .private.image_plotter import ImagePlotter
 from .private.line_plotter import LinePlotter as LinePlotter
 from .private.rect_multi_plotter import RectMultiPlotter as RectMultiPlotter
 from .private.split_axis_plotter import SplitAxisPlotter as SplitAxisPlotter
 from .private.split_axis_plotter_creator import SplitAxisPlotterCreator as SplitAxisPlotterCreator
-
 from .private import shared_axis_plotter
 
 #Code for serialization
